@@ -5,7 +5,7 @@ import yaml
 from dotenv import load_dotenv
 from termcolor2 import colored
 
-import load_config
+from dwhutils import load_config
 from dwhutils.DataVaultLoader import DataVaultLoader
 from dwhutils.MongoLoader import MongoLoader
 from dwhutils.TechFields import add_technical_col
