@@ -7,7 +7,7 @@ from pymongo import MongoClient
 from termcolor2 import colored
 import os
 from dotenv import load_dotenv
-import load_config
+from dwhutils import load_config
 warnings.filterwarnings("ignore")
 
 
