@@ -7,7 +7,7 @@ from dwhutils.TableReader import read_raw_sql_sat as r_sat
 from dwhutils.db_connection import connect_to_db
 import os
 from dotenv import load_dotenv
-import load_config
+from dwhutils import load_config
 
 class ReadEntity:
 
@@ -65,9 +65,12 @@ class ReadEntity:
                     entity.drop(columns=['index'], inplace=True)
                 elif self.config[self.entity_name]['tables'][t]['table_type'] == 'satellit':
                     _r_sat = r_sat(date=self.p_date, t_name=t, db_con=con, schema=self.layer)
-                    _r_sat.drop(
-                        columns=['index', 'processing_date_start', 'processing_date_end', 'createte_at', 'modified_at',
-                                 'record_source', 'diff_hk', 'mod_flg', 'load_domain'], inplace=True)
+                    try:
+                        _r_sat.drop(
+                            columns=['index', 'processing_date_start', 'processing_date_end', 'createte_at', 'modified_at',
+                                     'record_source', 'diff_hk', 'mod_flg', 'load_domain'], inplace=True)
+                    except:
+                        pass
                     dataframes[t] = _r_sat
 
             for k, v in dataframes.items():
