@@ -8,7 +8,7 @@ import yaml
 from sqlalchemy import MetaData
 from termcolor2 import colored
 
-import load_config
+from dwhutils import load_config
 from dwhutils.utils import divide_chunks
 
 
