@@ -1,16 +1,12 @@
 import pandas as pd
+from dwhutils.db_connection import connect_to_db
 from sqlalchemy import MetaData
 
-try:
-    from utils.db_connection import connect_to_db
-except ImportError:
-    from project.dags.utils.db_connection import connect_to_db
-
 
 def get_lkp_value(lkp_name: str):
     db_con = connect_to_db(layer='biz')
 
-    res = pd.read_sql_table(table_name=lkp_name.upper(),con=db_con)
+    res = pd.read_sql_table(table_name=lkp_name.upper(), con=db_con)
     results = res.to_dict('records')
 
     lkp = {}
@@ -44,4 +40,3 @@ def get_reverse_lkp_value(lkp_name: str, lkp_id):
     lkp = lkp[lkp['ID'] == lkp_id]
 
     return lkp['auspraegung'].values[0]
-
